// -*- C++ -*-
/*!
 * @file  MapImageSelect.cpp
 * @brief 地図データDBからタイル画像を取得し地図を作成する
 * @date $Date$
 *
 * @author 株式会社 東日本計算センター
 *
 * New BSD
 *
 * $Id$
 */

#include "MapImageSelect.h"
#include <opencv2\opencv.hpp>
#include "json.h"
#include <filesystem>
#include <mbstring.h>

// Module specification
// <rtc-template block="module_spec">
static const char* mapimageselect_spec[] =
  {
    "implementation_id", "MapImageSelect",
    "type_name",         "MapImageSelect",
    "description",       "地図データDBからタイル画像を取得し地図を作成する",
    "version",           "0.5",
    "vendor",            "EAC",
    "category",          "Image Control",
    "activity_type",     "PERIODIC",
    "kind",              "DataFlowComponent",
    "max_instance",      "1",
    "language",          "C++",
    "lang_type",         "compile",
    ""
  };
// </rtc-template>

/*!
 * @brief constructor
 * @param manager Maneger Object
 */
MapImageSelect::MapImageSelect(RTC::Manager* manager)
    // <rtc-template block="initializer">
  : RTC::DataFlowComponentBase(manager),
    m_inMapAdditinalDataInfoIn("inMapAdditinalDataInfo", m_inMapAdditinalDataInfo),
    m_inMapAdditinalDataIn("inMapAdditinalData", m_inMapAdditinalData),
    m_outMapImageStartGpsDataOut("outMapImageStartGpsData", m_outMapImageStartGpsData),
    m_outMapImageEndGpsDataOut("outMapImageEndGpsData", m_outMapImageEndGpsData),
    m_outMapImageDataOut("outMapImageData", m_outMapImageData),
    m_MapImageSelectReqServPort("MapImageSelectReqServ"),
    m_MapImageStsServPort("MapImageStsServ"),
    m_MapDataDBReqServPort("MapDataDBReqServ"),
    m_MapDataDBStsServPort("MapDataDBStsServ")

    // </rtc-template>
{
}

/*!
 * @brief destructor
 */
MapImageSelect::~MapImageSelect()
{
}


/*!
 * 地図画像セレクトRTCの初期化処理
 */
RTC::ReturnCode_t MapImageSelect::onInitialize()
{
#ifdef _DEBUG
	std::cout << "[debug]MapImageSelect::onInitialize" << std::endl;
#endif

  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers
  addInPort("inMapAdditinalDataInfo", m_inMapAdditinalDataInfoIn);
  addInPort("inMapAdditinalData", m_inMapAdditinalDataIn);
  
  // Set OutPort buffer
  addOutPort("outMapImageStartGpsData", m_outMapImageStartGpsDataOut);
  addOutPort("outMapImageEndGpsData", m_outMapImageEndGpsDataOut);
  addOutPort("outMapImageData", m_outMapImageDataOut);
  
  // Set service provider to Ports
  m_MapImageSelectReqServPort.registerProvider("MapImageReqSelectImage", "MapImageSelectReqServ::MapImageReqSelectImage", m_MapImageReqSelectImageProv);
  m_MapImageSelectReqServPort.registerProvider("MapImageReqScroll", "MapImageSelectReqServ::MapImageReqScroll", m_MapImageReqScrollProv);
  m_MapImageSelectReqServPort.registerProvider("MapImageReqAdjZoom", "MapImageSelectReqServ::MapImageReqAdjZoom", m_MapImageReqAdjZoomProv);
  m_MapImageSelectReqServPort.registerProvider("MapImageReqAdjMapChange", "MapImageSelectReqServ::MapImageReqAdjMapChange", m_MapImageReqAdjMapChangeProv);
  m_MapImageStsServPort.registerProvider("MapImageNotice", "MapImageStsServ::MapImageNotice", m_MapImageNoticeProv);
  
  // Set service consumers to Ports
  m_MapDataDBReqServPort.registerConsumer("MapDBReqGetAddDataInfo", "MapDataDBReqServ::MapDBReqGetAddDataInfo", m_MapDBReqGetAddDataInfoCons);
  m_MapDataDBReqServPort.registerConsumer("MapDBReqGetAddData", "MapDataDBReqServ::MapDBReqGetAddData", m_MapDBReqGetAddDataCons);
  m_MapDataDBStsServPort.registerConsumer("MapDataDBNotice", "MapDataDBStsServ::MapDataDBNotice", m_MapDataDBNoticeCons);
  
  // Set CORBA Service Ports
  addPort(m_MapImageSelectReqServPort);
  addPort(m_MapImageStsServPort);
  addPort(m_MapDataDBReqServPort);
  addPort(m_MapDataDBStsServPort);
  
  // </rtc-template>

  // <rtc-template block="bind_config">
  // </rtc-template>
  MapImgSelInit();
  
  return RTC::RTC_OK;
}

/*!
 * 地図画像セレクトRTCの終了処理
 */

RTC::ReturnCode_t MapImageSelect::onFinalize()
{
#ifdef _DEBUG
	std::cout << "[debug]MapImageSelect::onFinalize()" << std::endl;
#endif

  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t MapImageSelect::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t MapImageSelect::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*!
 * 地図画像セレクトRTCの開始処理
 */

RTC::ReturnCode_t MapImageSelect::onActivated(RTC::UniqueId ec_id)
{
#ifdef _DEBUG
	std::cout << "[debug]MapImageSelect::onActivated()" << std::endl;
#endif
	
  return RTC::RTC_OK;
}

/*!
 * 地図画像セレクトRTCの停止処理
 */

RTC::ReturnCode_t MapImageSelect::onDeactivated(RTC::UniqueId ec_id)
{
#ifdef _DEBUG
	std::cout << "[debug]MapImageSelect::onDeactivated()" << std::endl;
	cv::destroyAllWindows();
#endif
	MapImgSelInit();

  return RTC::RTC_OK;
}

/*!
 * 地図画像セレクトRTCの周期処理
 */

RTC::ReturnCode_t MapImageSelect::onExecute(RTC::UniqueId ec_id)
{
	uhword_type uhwResult = RESULT_ERROR;
	bool_type	blRet = FALSE;

	blRet = blMapImgSelMatrixTrigerSet();
	if(blRet){
		uhwResult = uhwMapImgSelMatrixCheck();
		if(uhwResult == RESULT_SUCCESS){
			uhwResult = uhwMapImgSelProcExe();
		}
		if(uhwResult == RESULT_ERROR){
			return RTC::RTC_ERROR;
		}
	}
	
  return RTC::RTC_OK;
}

/*!
 * 地図画像セレクトRTCのエラー遷移処理
 */

RTC::ReturnCode_t MapImageSelect::onAborting(RTC::UniqueId ec_id)
{
#ifdef _DEBUG
	std::cout << "[debug]MapImageSelect::onAborting()" << std::endl;
#endif

  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t MapImageSelect::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t MapImageSelect::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t MapImageSelect::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t MapImageSelect::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*=============================================================================
テーブル定義
==============================================================================*/

//マトリクステーブル
struct MatrixContens{
	uhword_type	uhwAct;			//アクション
	uhword_type	uhwMode;		//モード
};

struct MatrixContens MapImageSelMatrixTbl[][MODE_MAX] ={
	//非表示										//作成中									//表示
	{{ACT_NON,					MODE_NO_CHG		},{ACT_GET_MAPINFO,			MODE_NO_CHG		},{ACT_NON,					MODE_NO_CHG		}},	//地図画像付加情報取得正常終了
	{{ACT_NON,					MODE_NO_CHG		},{ACT_MAP_CREATE_ERROR,	MODE_DISP_OFF	},{ACT_NON,					MODE_NO_CHG		}},	//地図画像付加情報取得異常終了
	{{ACT_NON,					MODE_NO_CHG		},{ACT_GET_MAPDATA,			MODE_NO_CHG		},{ACT_NON,					MODE_NO_CHG		}},	//地図画像付加データ取得正常終了
	{{ACT_NON,					MODE_NO_CHG		},{ACT_MAP_CREATE_ERROR,	MODE_DISP_OFF	},{ACT_NON,					MODE_NO_CHG		}},	//地図画像付加データ取得異常終了
	{{ACT_MAP_CREATE_START,		MODE_CREATING	},{ACT_NON,					MODE_NO_CHG		},{ACT_MAP_CREATE_START,	MODE_CREATING	}},	//地図画像セレクト要求
	{{ACT_REQ_NOTICE_SUCCESS,	MODE_NO_CHG		},{ACT_NON,					MODE_NO_CHG		},{ACT_REQ_SCROLL,			MODE_CREATING	}},	//スクロール要求
	{{ACT_REQ_NOTICE_SUCCESS,	MODE_NO_CHG		},{ACT_NON,					MODE_NO_CHG		},{ACT_REQ_ZOOM_LEVEL,		MODE_CREATING	}},	//ズームレベル切り替え要求
	{{ACT_REQ_NOTICE_SUCCESS,	MODE_NO_CHG		},{ACT_NON,					MODE_NO_CHG		},{ACT_REQ_MAP_CHG,			MODE_CREATING	}},	//地図切り替え要求
};

//完了通知テーブル
uhword_type MapCreateNoticeTbl[2][4] ={
	//セレクト要求					//スクロール要求				//ズームレベル切り替え要求	//地図切り替え要求
	{MAPSEL_NOTICE_SELECT_SUCCESS,	MAPSEL_NOTICE_SCROLL_SUCCESS,	MAPSEL_NOTICE_ZOOM_SUCCESS,	MAPSEL_NOTICE_MAPCHG_SUCCESS	},	//正常終了
	{MAPSEL_NOTICE_SELECT_ERROR,	MAPSEL_NOTICE_SCROLL_ERROR,		MAPSEL_NOTICE_ZOOM_ERROR,	MAPSEL_NOTICE_MAPCHG_ERROR		},	//異常終了
};


/*****************************************************************************************
	サブルーチン
******************************************************************************************/
/*****************************************************************************************
*	Function Name		：MapImageSelectTrigCheck
*	Description			：サービスポートの要求をチェックしマトリクスの内部トリガを設定する
*	Argument			：なし
*	Return				：TRUE：トリガあり、FALSE：トリガなし
******************************************************************************************/
bool_type MapImageSelect::blMapImgSelMatrixTrigerSet(void)
{
	bool_type	blRet = FALSE;
	bool_type	blRet2 = FALSE;
	uhword_type uhwTriger = TRG_NON;

	blRet = blMapDBNoticeTrigCheck(uhwTriger);
	//地図作成中は他のトリガ要求のチェックを保留する
	if((m_uhwMatrixMode != MODE_CREATING) && (blRet == FALSE)){
		blRet = blReqSelectImageTrigCheck(uhwTriger);
		if(blRet == FALSE){
			blRet = blReqScrollTrigCheck(uhwTriger);
			if(blRet == FALSE){
				blRet = blReqAdjZoomTrigCheck(uhwTriger);
				if(blRet == FALSE){
					blRet = blReqAdjMapChgTrigCheck(uhwTriger);
				}
			}
		}
	}

	if((blRet == TRUE) && (uhwTriger != TRG_NON)){
		m_uhwMatrixTriger = uhwTriger;
		blRet2 = TRUE;
	}

	return blRet2;
}

/*******************************************************************************
*	Function Name		：uhwMapImgSelMatrixCheck
*	Description			：マトリクスチェック処理
*	Argument			：なし
*	Return				：RESULT_SUCCESS:正常終了、RESULT_ERROR：異常終了
*******************************************************************************/
uhword_type MapImageSelect::uhwMapImgSelMatrixCheck(void)
{
	uhword_type uhwMode = MODE_NO_CHG;

	if((m_uhwMatrixTriger >= TRG_MAX) || (m_uhwMatrixMode >= MODE_MAX)){
		return RESULT_ERROR;
	}

	m_uhwMatrixActID = MapImageSelMatrixTbl[m_uhwMatrixTriger][m_uhwMatrixMode].uhwAct;
	uhwMode = MapImageSelMatrixTbl[m_uhwMatrixTriger][m_uhwMatrixMode].uhwMode;

	//内部モードを更新
	if(uhwMode != MODE_NO_CHG){
		if(m_uhwMatrixMode != uhwMode){
			MapImgSelModeSet(uhwMode);
		}
	}

	return RESULT_SUCCESS;
}

/*****************************************************************************************
*	Function Name		：uhwProcExe
*	Description			：プロセス実行処理
*	Argument			：なし
*	Return				：RESULT_SUCCESS:正常終了、RESULT_ERROR：異常終了
******************************************************************************************/
uhword_type MapImageSelect::uhwMapImgSelProcExe(void)
{
	uhword_type uhwRet = RESULT_ERROR;

	//実行処理テーブル
	uhword_type(MapImageSelect::*RunProcTable[])(void) ={
		&MapImageSelect::uhwProcReqSelectImage,		//ACT_MAP_CREATE_START
		&MapImageSelect::uhwProcGetMapDBAddInfo,	//ACT_GET_MAPINFO
		&MapImageSelect::uhwProcGetMapDBAddData,	//ACT_GET_MAPDATA
		&MapImageSelect::uhwProcMapDBError,			//ACT_MAP_CREATE_ERROR
		&MapImageSelect::uhwProcScroll,				//ACT_REQ_SCROLL
		&MapImageSelect::uhwProcAdjZoom,			//ACT_REQ_ZOOM_LEVEL
		&MapImageSelect::uhwProcAdjMapChg,			//ACT_REQ_MAP_CHG
		&MapImageSelect::uhwProcReqNoticeSuccess,	//ACT_NOTICE_SUCCESS
		&MapImageSelect::uhwProcReqNoticeError,		//ACT_NOTICE_ERROR,
	};

	if(m_uhwMatrixActID == ACT_NON){
		//動作要求なしの場合、何もせず正常終了を返す
		return RESULT_SUCCESS;
	}

	//処理実行
	if(m_uhwMatrixActID < ACT_MAX){
		uhwRet = (this->*RunProcTable[m_uhwMatrixActID])();
#ifdef _DEBUG
		std::cout << "[debug]uhwMapImgSelProcExe():procid = " << m_uhwMatrixActID <<",Result = " << uhwRet << std::endl;
#endif
	}

	return uhwRet;
}

/*****************************************************************************************
*	Function Name		：blMapDBNoticeTrigCheck
*	Description			：地図データDB完了通知をチェックし内部イベントに変換する
*	Argument			：out：内部イベント
*	Return				：TRUE:トリガあり、FALSE：トリガなし
******************************************************************************************/
bool_type MapImageSelect::blMapDBNoticeTrigCheck(uhword_type &uhwTriger)
{
	bool_type	blRet = FALSE;
	uword_type	uwNotice = NOTICE_INIT;
	uword_type	uwParam = NOTICE_PARAM_INIT;

	uhwTriger = TRG_NON;

	if(blMapDataDBNoticeConsChk()){
		m_MapDataDBNoticeCons->GetMapDataDBNotice(uwNotice, uwParam);

		if((uwNotice == NOTICE_INIT) && (uwParam == NOTICE_PARAM_INIT)){
			//変化なし
			return blRet;
		}

		switch(uwNotice){
			case MAPDB_GET_ADD_INFO_SUCCESS:
				uhwTriger = TRG_MAPDB_GET_MAPINFO_SUCCESS;
				break;
			case MAPDB_GET_ADD_INFO_ERROR:
				uhwTriger = TRG_MAPDB_GET_MAPINFO_ERROR;
				break;
			case MAPDB_GET_ADD_DATA_SUCCESS:
				uhwTriger = TRG_MAPDB_GET_MAPDATA_SUCCESS;
				break;
			case MAPDB_GET_ADD_DATA_ERROR:
				uhwTriger = TRG_MAPDB_GET_MAPDATA_ERROR;
				break;
			default:
				break;
		}

		if(uhwTriger != TRG_NON){
			std::cout << "[debug]GetMapDataDBNotice()" << ",Param1 = " << uwNotice << ",Param2 = " << uwParam << std::endl;
			//完了通知初期化
			m_MapDataDBNoticeCons->usSetMapDataDBNotice(NOTICE_INIT, NOTICE_PARAM_INIT);
			m_uwMapDBNotice = uwNotice;
			blRet = TRUE;
		}
	}

	return blRet;
}

/*****************************************************************************************
*	Function Name		：blReqSelectImageTrigCheck
*	Description			：地図画像選択要求をチェックし内部イベントに変換する
*	Argument			：out：内部イベント
*	Return				：TRUE:トリガあり、FALSE：トリガなし
******************************************************************************************/
bool_type MapImageSelect::blReqSelectImageTrigCheck(uhword_type &uhwTriger)
{
	uword_type uwGroupId = GROUP_ID_NON;
	bool_type blRet = FALSE;

	uhwTriger = TRG_NON;

	m_MapImageReqSelectImageProv.GetMapImageReqSelectImage(uwGroupId);

	if(uwGroupId == GROUP_ID_NON){
		return FALSE;
	}

	if(uwGroupId != GROUP_ID_NON){
		std::cout << "[debug]GetMapImageReqSelectImage()" << ",Param1 = " << uwGroupId << std::endl;
		m_uwSelImageGroupId = uwGroupId;
		uhwTriger = TRG_REQ_MAP_IMAGE_SELECT;
		m_MapImageReqSelectImageProv.InitMapImageReqSelectImage();
		blRet = TRUE;
	}

	return blRet;
}

/*****************************************************************************************
*	Function Name		：blReqScrollTrigCheck
*	Description			：スクロール要求をチェックし内部イベントに変換する
*	Argument			：out：内部イベント
*	Return				：TRUE:トリガあり、FALSE：トリガなし
******************************************************************************************/
bool_type MapImageSelect::blReqScrollTrigCheck(uhword_type &uhwTriger)
{
	uword_type uwArrow = ARROW_DEF;
	bool_type blRet = FALSE;

	uhwTriger = TRG_NON;

	m_MapImageReqScrollProv.GetMapImageReqScroll(uwArrow);

	if(uwArrow != ARROW_OFF){
		std::cout << "[debug]GetMapImageReqScroll()" << ",Param1 = " << uwArrow << std::endl;
		uhwTriger = TRG_REQ_SCROLL;
		m_MapImageReqScrollProv.usSetMapImageReqScroll(ARROW_OFF);
		m_uwScrollArrow = uwArrow;
		blRet = TRUE;
	}

	return blRet;
}

/*****************************************************************************************
*	Function Name		：blReqAdjZoomTrigCheck
*	Description			：ズームレベル要求をチェックし内部イベントに変換する
*	Argument			：out：内部イベント
*	Return				：TRUE:トリガあり、FALSE：トリガなし
******************************************************************************************/
bool_type MapImageSelect::blReqAdjZoomTrigCheck(uhword_type &uhwTriger)
{
	uword_type uwAdjZoom = ZOOM_ADJ_OFF;
	bool_type blRet = FALSE;

	uhwTriger = TRG_NON;

	m_MapImageReqAdjZoomProv.GetMapImageReqAdjZoom(uwAdjZoom);

	if(uwAdjZoom != ZOOM_ADJ_OFF){
		std::cout << "[debug]GetMapImageReqAdjZoom()" << ",Param1 = " << uwAdjZoom << std::endl;
		m_uwAdjZoom = uwAdjZoom;
		uhwTriger = TRG_REQ_ADJ_ZOOMLEVEL;
		m_MapImageReqAdjZoomProv.usSetMapImageReqAdjZoom(ZOOM_ADJ_OFF);
		blRet = TRUE;
	}

	return blRet;
}

/*****************************************************************************************
*	Function Name		：blReqAdjMapChgTrigCheck
*	Description			：地図切り替え要求をチェックし内部イベントに変換する
*	Argument			：out：内部イベント
*	Return				：TRUE:トリガあり、FALSE：トリガなし
******************************************************************************************/
bool_type MapImageSelect::blReqAdjMapChgTrigCheck(uhword_type &uhwTriger)
{
	uword_type uwMapKind = MAP_CHENGE_DEF;
	bool_type blRet = FALSE;

	uhwTriger = TRG_NON;

	m_MapImageReqAdjMapChangeProv.GetMapImageReqAdjMapChange(uwMapKind);
	if(uwMapKind != m_uwMapKind){
		std::cout << "[debug]GetMapImageReqAdjMapChange()" << ",Param1 = " << uwMapKind << std::endl;
		uhwTriger = TRG_REQ_MAP_CHENGE;
		m_uwMapKind = uwMapKind;
		blRet = TRUE;
	}

	return blRet;
}

/*****************************************************************************************
*	Function Name		：uhwProcReqSelectImage
*	Description			：地図画像選択要求を行う
*	Argument			：なし
*	Return				：RESULT_SUCCESS:正常終了、RESULT_ERROR：異常終了
******************************************************************************************/
uhword_type MapImageSelect::uhwProcReqSelectImage(void)
{
	uhword_type uhwServResult = RESULT_NACK;
	uhword_type uhwResult = RESULT_ERROR;

	m_uwMapCreateKind = CREATE_KIND_SELECT;

	m_uwZoomLevel = ZOOM_LEVEL_20;
//	m_uwZoomLevel = ZOOM_LEVEL_DEF;
	memset(&m_stMapDBAddInfo,0,sizeof(MapDBAddInfo_st));
	MapAddDataInit();

	if(blMapDBDBReqGetAddDataInfoConsChk()){
		uhwServResult = m_MapDBReqGetAddDataInfoCons->usSetMapDBReqGetAddDataInfo(m_uwSelImageGroupId,m_uwZoomLevel);
		if(uhwServResult == RESULT_ACK){
			std::cout << "[debug]usSetMapDBReqGetAddDataInfo = " << uhwServResult
				<< ",param1 = " << m_uwSelImageGroupId
				<< ",param2 = " << m_uwZoomLevel
				<< std::endl;
			uhwResult = RESULT_SUCCESS;
		}
		else{
			std::cout << "[error]usSetMapDBReqGetAddDataInfo = " << uhwServResult
					  << ",param1 = " << m_uwSelImageGroupId
					  << ",param2 = " << m_uwZoomLevel
					  << std::endl;
			//地図画像セレクトRTCへの要求に対する応答を返す
			MapImageNotice(RESULT_ERROR);
		}
	}

	return uhwResult;
}

/*****************************************************************************************
*	Function Name		：uhwProcGetMapDBAddInfo
*	Description			：地図データDBのサービスポートから画像付加データ情報(json形式)を取得する
*	Argument			：なし
*	Return				：RESULT_SUCCESS:正常終了、RESULT_ERROR：異常終了
******************************************************************************************/
uhword_type MapImageSelect::uhwProcGetMapDBAddInfo(void)
{
	std::string strAddDataInfo = "";
	Json::Reader reader;
	Json::Value	Val;
	uhword_type uhwResult = RESULT_ERROR;
	MapDBAddInfo_st stAddInfo;
	std::string strAddDataRep = "";

	memset(&stAddInfo, 0, sizeof(MapDBAddInfo_st));

	if(m_inMapAdditinalDataInfoIn.isNew()){
		m_inMapAdditinalDataInfoIn.read();
		strAddDataInfo = m_inMapAdditinalDataInfo.data;
	}

	//空文字の確認
	if(strAddDataInfo != ""){
//		std::cout << "Input Json Data" << strAddDataInfo << std::endl;

		//パーサーを通す前に置換
		strAddDataRep = strMapJsonDataReplace(strAddDataInfo);

		reader.parse(strAddDataRep, Val);
		stAddInfo.uwTileBaseCodeX = (uword_type)Val[MAPDATA_TILE_BASECODE_X].asDouble();
		stAddInfo.uwTileBaseCodeY = (uword_type)Val[MAPDATA_TILE_BASECODE_Y].asDouble();
		stAddInfo.uwTileNumX = Val[MAPDATA_TILE_NUM_X].asUInt();
		stAddInfo.uwTileNumY = Val[MAPDATA_TILE_NUM_Y].asUInt();
		stAddInfo.uwKeepZoomLevel = Val[MAPDATA_KEEP_ZOOM_LEVEL].asUInt();

		//タイルの数を確認
		if((stAddInfo.uwTileNumX == 0) || (stAddInfo.uwTileNumY == 0)){
			std::cout << "[error]No tile!! = " << stAddInfo.uwTileNumX << ", " << stAddInfo.uwTileNumY << std::endl;
			goto MAPDB_ADD_INFO_ERR;
		}

		//ズームレベル保有数の上限確認(ズームレベル18～21まで)
		if((stAddInfo.uwKeepZoomLevel == 0) || (stAddInfo.uwKeepZoomLevel > KEEP_ZOOM_LEVEL_MAX)){
			std::cout << "[error]Zoom level keep num!! = " << stAddInfo.uwKeepZoomLevel << std::endl;
			goto MAPDB_ADD_INFO_ERR;
		}

		//メンバ変数にコピーする
		memcpy(&m_stMapDBAddInfo, &stAddInfo, sizeof(MapDBAddInfo_st));

		//一枚目のタイル画像取得要求
		uhwResult = uhwGetStartTileData();
		if(uhwResult == RESULT_ERROR){
			goto MAPDB_ADD_INFO_ERR;
		}
	}
	else{
		std::cout << "[error]Map info data is empty!!" << std::endl;
		goto MAPDB_ADD_INFO_ERR;
	}

	return RESULT_SUCCESS;

MAPDB_ADD_INFO_ERR:
	//地図画像セレクトRTCへの要求に対する応答を返す
	MapImageNotice(RESULT_ERROR);
	return RESULT_ERROR;

}

/*****************************************************************************************
*	Function Name		：uhwProcGetMapDBAddData
*	Description			：地図データDBのサービスポートから画像付加データ(json形式)を取得する
*	Argument			：なし
*	Return				：RESULT_SUCCESS:正常終了、RESULT_ERROR：異常終了
******************************************************************************************/
uhword_type MapImageSelect::uhwProcGetMapDBAddData(void)
{
	std::string strAddData = "";
	Json::Reader reader;
	Json::Value	Val;
	uhword_type uhwResult = RESULT_ERROR;
	uword_type uwCntMax = (m_stMapDBAddInfo.uwTileNumX * m_stMapDBAddInfo.uwTileNumY);
	MapDBAddData_st stAddData;
	std::string strConvSjisName = "";
	std::string strConvSjisPath = "";
	std::string strAddDataRep = "";

	if((m_uwMapDBGetCnt < uwCntMax) && (m_uwMapDBGetCnt < TILE_MAX_NUM)){
		if(m_inMapAdditinalDataIn.isNew()){
			m_inMapAdditinalDataIn.read();
			strAddData = m_inMapAdditinalData.data;
		}

		//空文字の確認
		if(strAddData != ""){
//			std::cout << "Input Json Data" << strAddData << std::endl;

			//パーサーを通す前に置換
			strAddDataRep = strMapJsonDataReplace(strAddData);
			reader.parse(strAddDataRep, Val);

			//UTF-8→Shift-jis変換
			strConvSjisName = strUTF8toSjis(Val[MAPDATA_TILE_NAME].asString());
			if(strConvSjisName == ""){
				goto MAPDB_ADD_DATA_ERR;
			}
			stAddData.strTileName = strConvSjisName;

			//UTF-8→Shift-jis変換
			strConvSjisPath = strUTF8toSjis(Val[MAPDATA_FOLDER_PATH].asString());
			if(strConvSjisPath == ""){
				goto MAPDB_ADD_DATA_ERR;
			}
			stAddData.strFolderPath = strConvSjisPath;

			//UTF-8→Shift-jis変換
			strConvSjisPath = strUTF8toSjis(Val[MAPDATA_CREATE_DATE].asString());
			if(strConvSjisPath == ""){
				goto MAPDB_ADD_DATA_ERR;
			}
			stAddData.strCreateDate = strConvSjisPath;

			//UTF-8→Shift-jis変換
			strConvSjisPath = strUTF8toSjis(Val[MAPDATA_PLAN_NAME].asString());
			if(strConvSjisPath == ""){
				goto MAPDB_ADD_DATA_ERR;
			}
			stAddData.strSyntesisPlanName = strConvSjisPath;

			stAddData.uwZoomLevel = (uword_type)Val[MAPDATA_ZOOM_LEVEL].asDouble();
			stAddData.uwTileCodeX = (uword_type)Val[MAPDATA_TILECODE_X].asDouble();
			stAddData.uwTileCodeY = (uword_type)Val[MAPDATA_TILECODE_Y].asDouble();
			stAddData.dStartLatitude = Val[MAPDATA_START_LATITUDE].asDouble();
			stAddData.dStartLongitude = Val[MAPDATA_START_LONGITUDE].asDouble();
			stAddData.dEndLatitude = Val[MAPDATA_END_LATITUDE].asDouble();
			stAddData.dEndLongitude = Val[MAPDATA_END_LONGITUDE].asDouble();

			//付加データを受信したタイミングで取得カウントをインクリメント
			m_uwMapDBGetCnt ++;
		}
		else{
			std::cout << "[error]Map data is empty!!" << std::endl;
			goto MAPDB_ADD_DATA_ERR;
		}

		//サービスポートから取得した地図画像付加データの範囲チェックを行う
		uhwResult = uhwMapDataRangeCheck(stAddData);
		if(uhwResult == RESULT_ERROR){
			goto MAPDB_ADD_DATA_ERR;
		}

		//範囲チェック後にメンバー変数にコピー
		m_stMapDBAddData.stTile[(m_uwMapDBGetCnt -1)].strTileName = stAddData.strTileName;
		m_stMapDBAddData.stTile[(m_uwMapDBGetCnt -1)].strFolderPath = stAddData.strFolderPath;
		m_stMapDBAddData.stTile[(m_uwMapDBGetCnt -1)].uwZoomLevel = stAddData.uwZoomLevel;
		m_stMapDBAddData.stTile[(m_uwMapDBGetCnt -1)].uwTileCodeX = stAddData.uwTileCodeX;
		m_stMapDBAddData.stTile[(m_uwMapDBGetCnt -1)].uwTileCodeY = stAddData.uwTileCodeY;
		m_stMapDBAddData.stTile[(m_uwMapDBGetCnt -1)].dStartLatitude = stAddData.dStartLatitude;
		m_stMapDBAddData.stTile[(m_uwMapDBGetCnt -1)].dStartLongitude = stAddData.dStartLongitude;
		m_stMapDBAddData.stTile[(m_uwMapDBGetCnt -1)].dEndLatitude = stAddData.dEndLatitude;
		m_stMapDBAddData.stTile[(m_uwMapDBGetCnt -1)].dEndLongitude = stAddData.dEndLongitude;
		m_stMapDBAddData.stTile[(m_uwMapDBGetCnt -1)].strCreateDate = stAddData.strCreateDate;
		m_stMapDBAddData.stTile[(m_uwMapDBGetCnt -1)].strSyntesisPlanName = stAddData.strSyntesisPlanName;

		//続きのタイル画像データ取得要求を行う
		uhwResult = uhwGetNextTileData();
		if(uhwResult == RESULT_ERROR){
			goto MAPDB_ADD_DATA_ERR;
		}

		if((m_uwMapDBGetCnt == uwCntMax) || (m_uwMapDBGetCnt == TILE_MAX_NUM)){
			//タイル画像を繋ぎ合わせて地図画像を生成
			std::cout << "[debug]Json data get complete!!" << std::endl;
			uhwResult = uhwCreateMapImage();
			if(uhwResult == RESULT_ERROR){
				goto MAPDB_ADD_DATA_ERR;
			}
			else{
				//地図画像セレクトRTCへの要求に対する応答を返す
				MapImageNotice(RESULT_SUCCESS);
				MapImgSelModeSet(MODE_DISP_ON);
			}
		}
	}
	else{
		goto MAPDB_ADD_DATA_ERR;
	}
	return RESULT_SUCCESS;

MAPDB_ADD_DATA_ERR:
	//地図画像セレクトRTCへの要求に対する応答を返す
	MapImageNotice(RESULT_ERROR);
	return RESULT_ERROR;

}

/*****************************************************************************************
*	Function Name		：uhwProcMapDBError
*	Description			：地図データDBのエラー通知時の処理
*	Argument			：なし
*	Return				：RESULT_SUCCESS:正常終了、RESULT_ERROR：異常終了
******************************************************************************************/
uhword_type MapImageSelect::uhwProcMapDBError(void)
{
	uhword_type uhwResult = RESULT_ERROR;

	if((m_uhwMatrixTriger == TRG_MAPDB_GET_MAPINFO_ERROR) || (m_uhwMatrixTriger == TRG_MAPDB_GET_MAPDATA_ERROR)){
		//地図画像セレクトRTCへの要求に対する応答を返す
		MapImageNotice(uhwResult);
	}

	return uhwResult;
}

/*****************************************************************************************
*	Function Name		：uhwProcScroll
*	Description			：地図スクロール動作を制御する
*	Argument			：なし
*	Return				：RESULT_SUCCESS:正常終了、RESULT_ERROR：異常終了
******************************************************************************************/
uhword_type MapImageSelect::uhwProcScroll(void)
{
	uword_type uwMapImageCodeX = 0;
	uword_type uwMapImageCodeY = 0;
	uhword_type uhwResult = RESULT_ERROR;

	m_uwMapCreateKind = CREATE_KIND_SCROLL;

#ifdef _DEBUG
	cv::destroyAllWindows();
#endif

	//今回の地図画像は正方形のためここで、タイル画像総数が8×8以上か確認する
	if((m_stMapDBAddInfo.uwTileNumX <= TILE_X_MAXNUM) && (m_stMapDBAddInfo.uwTileNumY <= TILE_Y_MAXNUM)){
		//スクロール可能な画像がないため後続の処理は実行せず正常終了を返す
		goto CAN_NOT_SCROLL;
	}

	switch(m_uwScrollArrow){
		case ARROW_UP:
			if(m_uwTileNoYEnd > TILE_Y_MAXNUM){
				m_uwTileNoYStart = ((m_uwTileNoYEnd -1) - (TILE_Y_MAXNUM -1));
			}
			else{
				goto CAN_NOT_SCROLL;
			}
			break;
		case ARROW_DOWN:
			if((m_uwTileNoYEnd >= TILE_Y_MAXNUM) && (m_uwTileNoYEnd < m_stMapDBAddInfo.uwTileNumY)){
				m_uwTileNoYStart = ((m_uwTileNoYEnd +1) - (TILE_Y_MAXNUM -1));
			}
			else{
				goto CAN_NOT_SCROLL;
			}
			break;
		case ARROW_LEFT:
			if(m_uwTileNoXEnd > TILE_X_MAXNUM){
				m_uwTileNoXStart = ((m_uwTileNoXEnd -1) - (TILE_X_MAXNUM -1));
			}
			else{
				goto CAN_NOT_SCROLL;
			}
			break;
		case ARROW_RIGHT:
			if((m_uwTileNoXEnd >= TILE_X_MAXNUM) && (m_uwTileNoXEnd < m_stMapDBAddInfo.uwTileNumX)){
				m_uwTileNoXStart = ((m_uwTileNoXEnd +1) - (TILE_X_MAXNUM -1));
			}
			else{
				goto CAN_NOT_SCROLL;
			}
			break;
		default:
			goto SCROLL_ERROR;
	}

	m_uwTileNoXEnd = m_uwTileNoXStart;
	m_uwTileNoYEnd = m_uwTileNoYStart;

	uwMapImageCodeX = (m_stMapDBAddInfo.uwTileBaseCodeX + (m_uwTileNoXStart -1));
	uwMapImageCodeY = (m_stMapDBAddInfo.uwTileBaseCodeY + (m_uwTileNoYStart -1));

	//タイル画像取得前に初期化
	MapAddDataInit();
	//一枚目のタイル画像取得要求を行う
	uhwResult = uhwMapDBReqGetAddData(uwMapImageCodeX, uwMapImageCodeY);
	if(uhwResult == RESULT_SUCCESS){
		m_uwMapDBGetCnt = 0;
		m_uwTileXGetCnt = 0;
		m_uwTileYGetCnt = 0;
	}
	else{
		goto SCROLL_ERROR;
	}

	return RESULT_SUCCESS;

CAN_NOT_SCROLL:
	//スクロール可能なタイル画像がない場合、動作せず正常終了を返す
	std::cout << "[warning]Can not scroll!! "
		<< "m_uwScrollArrow = " << m_uwScrollArrow
		<< "m_stMapDBAddInfo.uwTileNumX = " << m_stMapDBAddInfo.uwTileNumX
		<< ",m_stMapDBAddInfo.uwTileNumY = " << m_stMapDBAddInfo.uwTileNumY
		<< ",uwTileNoX = " << m_uwTileNoXStart
		<< ",m_uwTileNoY = " << m_uwTileNoYStart << std::endl;
	MapImageNotice(RESULT_ERROR);
	MapImgSelModeSet(MODE_DISP_ON);
	return RESULT_SUCCESS;

SCROLL_ERROR:
	MapImageNotice(RESULT_ERROR);
	return RESULT_ERROR;

}

/*****************************************************************************************
*	Function Name		：uhwProcAdjZoom
*	Description			：ズームレベル切り替えを制御する
*	Argument			：なし
*	Return				：RESULT_SUCCESS:正常終了、RESULT_ERROR：異常終了
******************************************************************************************/
uhword_type MapImageSelect::uhwProcAdjZoom(void)
{
	uhword_type uhwServResult = RESULT_NACK;
	uhword_type uhwResult = RESULT_ERROR;

	m_uwMapCreateKind = CREATE_KIND_ZOOM;

#ifdef _DEBUG
	cv::destroyAllWindows();
#endif

	//ズームレベル調整可能か確認
	uhwResult = uhwZoomLevelAdjCheck();
	if(uhwResult == RESULT_ERROR){
		//DBにズームレベルが登録されていないため動作せず正常終了を返す
		MapImageNotice(RESULT_ERROR);
		MapImgSelModeSet(MODE_DISP_ON);
		return RESULT_SUCCESS;
	}

	//ズームレベルが切り替わる時には、DBから情報を取り直す
	if(blMapDBDBReqGetAddDataInfoConsChk()){
		//タイル画像取得前に初期化
		MapAddDataInit();
		uhwServResult = m_MapDBReqGetAddDataInfoCons->usSetMapDBReqGetAddDataInfo(m_uwSelImageGroupId,m_uwZoomLevel);
		if(uhwServResult == RESULT_ACK){
			std::cout << "[debug]usSetMapDBReqGetAddDataInfo = " << uhwServResult
				<< ",param1 = " << m_uwSelImageGroupId
				<< ",param2 = " << m_uwZoomLevel
				<< std::endl;
			uhwResult = RESULT_SUCCESS;
		}
		else{
			std::cout << "[error]usSetMapDBReqGetAddDataInfo = " << uhwServResult
					  << ",param1 = " << m_uwSelImageGroupId
					  << ",param2 = " << m_uwZoomLevel
					  << std::endl;
			//地図画像セレクトRTCへの要求に対する応答を返す
			MapImageNotice(RESULT_ERROR);
			uhwResult = RESULT_ERROR;
		}
	}

	return uhwResult;
}

/*****************************************************************************************
*	Function Name		：uhwProcAdjMapChg
*	Description			：地図切り替えを制御する
*	Argument			：なし
*	Return				：RESULT_SUCCESS:正常終了、RESULT_ERROR：異常終了
******************************************************************************************/
uhword_type MapImageSelect::uhwProcAdjMapChg(void)
{
	uword_type uwMapImageCodeX = 0;
	uword_type uwMapImageCodeY = 0;
	uhword_type uhwResult = RESULT_ERROR;

	m_uwMapCreateKind = CREATE_KIND_MAP_CHENGE;

#ifdef _DEBUG
	cv::destroyAllWindows();
#endif

	uhwResult = uhwCreateMapImage();

	if(uhwResult == RESULT_SUCCESS){
		MapImageNotice(RESULT_SUCCESS);
		MapImgSelModeSet(MODE_DISP_ON);
	}
	else{
		MapImageNotice(RESULT_ERROR);
	}

	return uhwResult;
}

/*****************************************************************************************
*	Function Name		：uhwProcReqNoticeSuccess
*	Description			：地図画像セレクトコンポーネントへの要求に対して正常終了を通知する
*	Argument			：なし
*	Return				：RESULT_SUCCESS:正常終了、RESULT_ERROR：異常終了
******************************************************************************************/
uhword_type MapImageSelect::uhwProcReqNoticeSuccess(void)
{
	bool_type blTrigSet = TRUE;

	switch(m_uhwMatrixTriger){
		case TRG_REQ_MAP_IMAGE_SELECT:
			m_uwMapCreateKind = CREATE_KIND_SELECT;
			break;
		case TRG_REQ_SCROLL:
			m_uwMapCreateKind = CREATE_KIND_SCROLL;
			break;
		case TRG_REQ_ADJ_ZOOMLEVEL:
			m_uwMapCreateKind = CREATE_KIND_ZOOM;
			break;
		case TRG_REQ_MAP_CHENGE:
			m_uwMapCreateKind = CREATE_KIND_MAP_CHENGE;
			break;
		default:
			blTrigSet = FALSE;
			break;
	}

	if(blTrigSet){
		//地図画像セレクトRTCへの要求に対する応答を返す
		MapImageNotice(RESULT_SUCCESS);
	}

	return RESULT_SUCCESS;
}

/*****************************************************************************************
*	Function Name		：uhwProcReqNoticeError
*	Description			：地図画像セレクトコンポーネントへの要求に対して異常終了を通知する
*	Argument			：なし
*	Return				：RESULT_SUCCESS:正常終了、RESULT_ERROR：異常終了
******************************************************************************************/
uhword_type MapImageSelect::uhwProcReqNoticeError(void)
{
	bool_type blTrigSet = TRUE;

	switch(m_uhwMatrixTriger){
	case TRG_REQ_MAP_IMAGE_SELECT:
		m_uwMapCreateKind = CREATE_KIND_SELECT;
		break;
	case TRG_REQ_SCROLL:
		m_uwMapCreateKind = CREATE_KIND_SCROLL;
		break;
	case TRG_REQ_ADJ_ZOOMLEVEL:
		m_uwMapCreateKind = CREATE_KIND_ZOOM;
		break;
	case TRG_REQ_MAP_CHENGE:
		m_uwMapCreateKind = CREATE_KIND_MAP_CHENGE;
		break;
	default:
		blTrigSet = FALSE;
		break;
	}

	if(blTrigSet){
		//地図画像セレクトRTCへの要求に対する応答を返す
		MapImageNotice(RESULT_ERROR);
	}

	return RESULT_SUCCESS;
}

/*****************************************************************************************
*	Function Name		：uhwMapDBReqGetAddData
*	Description			：地図データDBへ画像付加データ取得要求を行う
*	Argument			：なし
*	Return				：RESULT_SUCCESS:正常終了、RESULT_ERROR：異常終了
******************************************************************************************/
uhword_type MapImageSelect::uhwMapDBReqGetAddData(uword_type uwMapImageCodeX, uword_type uwMapImageCodeY)
{
	uhword_type uhwServResult = RESULT_NACK;
	uhword_type uhwResult = RESULT_ERROR;

	//一枚目のタイル画像取得要求を行う
	if(blMapDBReqGetAddDataConsChk()){
		uhwServResult = m_MapDBReqGetAddDataCons->usSetMapDBReqGetAddData(m_uwSelImageGroupId, m_uwZoomLevel, uwMapImageCodeX, uwMapImageCodeY);
		if(uhwServResult == RESULT_ACK){
			std::cout << "[debug]usSetMapDBReqGetAddData = " << uhwServResult 
				<< ",param1 = " << m_uwSelImageGroupId
				<< ",param2 = " << m_uwZoomLevel
				<< ",param3 = " << uwMapImageCodeX
				<< ",param4 = " << uwMapImageCodeY
				<< std::endl;
			uhwResult = RESULT_SUCCESS;
		}
		else{
			//エラーメッセージ
			std::cout << "[error]usSetMapDBReqGetAddData = " << uhwServResult
				<< ",param1 = " << m_uwSelImageGroupId
				<< ",param2 = " << m_uwZoomLevel
				<< ",param3 = " << uwMapImageCodeX
				<< ",param4 = " << uwMapImageCodeY
				<< std::endl;
		}
	}

	return uhwResult;
}

/*****************************************************************************************
*	Function Name		：uhwGetStartTileData
*	Description			：一枚目のタイル画像取得要求を行う
*	Argument			：なし
*	Return				：RESULT_SUCCESS:正常終了、RESULT_ERROR：異常終了
******************************************************************************************/
uhword_type MapImageSelect::uhwGetStartTileData(void)
{
	uword_type uwMapImageCodeX = 0;
	uword_type uwMapImageCodeY = 0;
	uhword_type uhwServResult = RESULT_NACK;
	uhword_type uhwResult = RESULT_ERROR;

	//縦軸方向にタイルが8枚以上ある場合、中心を表示できるようタイル座標を調整する
	if(m_stMapDBAddInfo.uwTileNumX > TILE_X_MAXNUM){
		m_uwTileNoXStart = ((m_stMapDBAddInfo.uwTileNumX/2) - ((TILE_X_MAXNUM/2) -1));
	}
	else{
		m_uwTileNoXStart = 1;
	}

	uwMapImageCodeX = (m_stMapDBAddInfo.uwTileBaseCodeX + (m_uwTileNoXStart -1));
	m_uwTileNoXEnd = m_uwTileNoXStart;

	//横軸方向にタイルが8枚以上ある場合、中心を表示できるようタイル座標を調整する
	if(m_stMapDBAddInfo.uwTileNumY > TILE_Y_MAXNUM){
		m_uwTileNoYStart = ((m_stMapDBAddInfo.uwTileNumY/2) - ((TILE_Y_MAXNUM/2) -1));
	}
	else{
		m_uwTileNoYStart = 1;
	}

	uwMapImageCodeY = (m_stMapDBAddInfo.uwTileBaseCodeY + (m_uwTileNoYStart -1));
	m_uwTileNoYEnd = m_uwTileNoYStart;

	//一枚目のタイル画像取得要求を行う
	uhwResult = uhwMapDBReqGetAddData(uwMapImageCodeX,uwMapImageCodeY);
	if(uhwResult == RESULT_SUCCESS){
		m_uwMapDBGetCnt = 0;
		m_uwTileXGetCnt = 0;
		m_uwTileYGetCnt = 0;
	}

	return uhwResult;
}

/*****************************************************************************************
*	Function Name		：uhwGetNextTileData
*	Description			：続きのタイル画像取得要求を行う
*	Argument			：なし
*	Return				：RESULT_SUCCESS:正常終了、RESULT_ERROR：異常終了
******************************************************************************************/
uhword_type MapImageSelect::uhwGetNextTileData(void)
{
	uword_type uwMapImageCodeX = 0;
	uword_type uwMapImageCodeY = 0;
	uhword_type uhwServResult = RESULT_NACK;
	uhword_type uhwResult = RESULT_ERROR;
	bool_type blTileY = FALSE;

	//取得するタオル座標Xを算出
	if(m_uwTileNoXEnd < m_stMapDBAddInfo.uwTileNumX){
		m_uwTileXGetCnt ++;
		if(m_uwTileXGetCnt < TILE_X_MAXNUM){
			m_uwTileNoXEnd ++;
		}
		else{
			blTileY = TRUE;
		}
	}
	else{
		blTileY = TRUE;
	}

	if(blTileY){
		//取得するタオル座標Yを算出
		if(m_uwTileNoYEnd < m_stMapDBAddInfo.uwTileNumY){
			m_uwTileYGetCnt ++;
			if(m_uwTileYGetCnt < TILE_Y_MAXNUM){
				m_uwTileNoYEnd ++;
				m_uwTileNoXEnd = m_uwTileNoXStart;
				m_uwTileXGetCnt = 0;
			}
			else{
				//全タイル取得済みの場合、画像結合処理を動作させるため正常終了を返す。
				return RESULT_SUCCESS;
			}
		}
		else{
			//全タイル取得済みの場合、画像結合処理を動作させるため正常終了を返す。
			return RESULT_SUCCESS;
		}
	}

	uwMapImageCodeX = (m_stMapDBAddInfo.uwTileBaseCodeX + (m_uwTileNoXEnd - 1));
	uwMapImageCodeY = (m_stMapDBAddInfo.uwTileBaseCodeY + (m_uwTileNoYEnd - 1));

	//二枚目以降のタイル画像取得要求を行う
	uhwResult = uhwMapDBReqGetAddData(uwMapImageCodeX,uwMapImageCodeY);

	return uhwResult;
}

/*****************************************************************************************
*	Function Name		：uhwCreateMapImage
*	Description			：地図画像を作成する
*	Argument			：なし
*	Return				：RESULT_SUCCESS:正常終了、RESULT_ERROR：異常終了
******************************************************************************************/
uhword_type MapImageSelect::uhwCreateMapImage(void)
{
	std::string strFolderPath = "";
	std::string stTotalPath = "";
	uword_type uwTotalwidth = 0;
	uword_type uwTotalHeight = 0;
	uhword_type uhwLoopX = 0;
	uhword_type uhwLoopY = 0;
	uhword_type uhwLoopXMax = (m_uwTileNoXEnd - m_uwTileNoXStart) + 1;
	uhword_type uhwLoopYMax = (m_uwTileNoYEnd - m_uwTileNoYStart) + 1;
	uhword_type uhwTileCnt= 0;
	cv::Mat last;
	bool_type blXFirstLoop = TRUE;
	std::ostringstream oss;
	uhword_type uhwResult = RESULT_ERROR;

	//初期化
	oss.str("");
	oss.clear(std::stringstream::goodbit);

	// ファイルを読み込み，結合後のサイズを決定
	std::vector<cv::Mat> src_img;
	for(uhwLoopY = 0; uhwLoopY < uhwLoopYMax; uhwLoopY++) {
		for(uhwLoopX = 0; uhwLoopX < uhwLoopXMax; uhwLoopX++){
//			uhwTileCnt = (uhwLoopY * uhwLoopYMax + uhwLoopX);
			//フォルダパスを地図種別に合わせて置換
			strFolderPath = strFolderPathReplace(m_stMapDBAddData.stTile[uhwTileCnt].strFolderPath,m_uwMapKind);
			if(strFolderPath == ""){
				return RESULT_ERROR;
			}
			oss << MAP_BASE_FOLDER_PATH << TILE_FOLDER << strFolderPath << "/" << m_stMapDBAddData.stTile[uhwTileCnt].strTileName;
			stTotalPath = oss.str();
			src_img.push_back(cv::imread(stTotalPath));
			last = src_img.back();
			if(last.empty()){
				std::cout << "Input image read error!! = " << stTotalPath << std::endl;
				return RESULT_ERROR;
			}
			if(blXFirstLoop){
				uwTotalwidth += last.cols;
			}
			//フォルダパス初期化
			oss.str("");
			oss.clear(std::stringstream::goodbit);
			uhwTileCnt ++;
		}
		blXFirstLoop = FALSE;
		if(uhwLoopY < uhwLoopYMax){
			uwTotalHeight += last.rows;
		}
	}

	uhwTileCnt = 0;

	// ROIを利用して，DBから取得したタイル画像を結合
	cv::Mat combined_img(cv::Size(uwTotalwidth, uwTotalHeight),CV_8UC3);

	//生成した地図画像が破損していないか確認
	if((combined_img.cols == 0) || (combined_img.rows == 0)){
		std::cout << "[error]Map Image is broken!! = " << combined_img.cols << ", " << combined_img.rows << std::endl;
		return RESULT_ERROR;
	}

	std::vector<cv::Mat>::iterator it = src_img.begin(),it_end = src_img.end();
	cv::Rect roi_rect;
	for(; it!=it_end; ++it) {
		roi_rect.width = it->cols;
		roi_rect.height = it->rows;
		cv::Mat roi(combined_img,roi_rect);
		it->copyTo(roi);
		uhwTileCnt ++;
		if(uhwTileCnt < uhwLoopXMax){
			roi_rect.x += it->cols;
		}
		else{
			uhwTileCnt = 0;
			roi_rect.y += it->rows;
			roi_rect.x = 0;
		}
	}

	//pngファイルへの保存
	cv::imwrite(MAP_IMAGE_FAILENAME, combined_img);

	//データポートに生成した地図画像をセットする
	sword_type swlength = ((combined_img.channels() * combined_img.cols) * combined_img.rows);
	m_outMapImageData.width = combined_img.cols;
	m_outMapImageData.height = combined_img.rows;
	m_outMapImageData.pixels.length(swlength);
	::memcpy((void *)&(m_outMapImageData.pixels[0]),combined_img.data,swlength);
	m_outMapImageDataOut.write();

	//GPS出力
	uhwResult = uhwGetGpsData();
	if(uhwResult == RESULT_ERROR){
		std::cout << "gps data out error!!" << std::endl;
		return RESULT_ERROR;
	}

#ifdef _DEBUG
	//window表示用の処理
//	cv::namedWindow("Combined Image",CV_WINDOW_AUTOSIZE);
//	cv::imshow("Combined Image",combined_img);
//	cv::waitKey(0);
#endif

	return RESULT_SUCCESS;
}

/*****************************************************************************************
*	Function Name		：uhwGetGpsData
*	Description			：Gpsデータ出力処理
*	Argument			：なし
*	Return				：RESULT_SUCCESS:正常終了、RESULT_ERROR：異常終了
******************************************************************************************/
uhword_type MapImageSelect::uhwGetGpsData(void)
{
	uhword_type uhwResult = RESULT_ERROR;

	if((m_uwMapDBGetCnt != 0) && (m_uwMapDBGetCnt <= TILE_MAX_NUM)){
		//地図画像の緯度、経度座標を送信
		m_outMapImageStartGpsData.latitude = m_stMapDBAddData.stTile[0].dStartLatitude;
		m_outMapImageStartGpsData.longitude = m_stMapDBAddData.stTile[0].dStartLongitude;
		m_outMapImageStartGpsData.fixType = GPS_FIX_NORMAL;
		m_outMapImageEndGpsData.latitude = m_stMapDBAddData.stTile[(m_uwMapDBGetCnt -1)].dEndLatitude;
		m_outMapImageEndGpsData.longitude = m_stMapDBAddData.stTile[(m_uwMapDBGetCnt -1)].dEndLongitude;
		m_outMapImageEndGpsData.fixType = GPS_FIX_NORMAL;

		m_outMapImageStartGpsDataOut.write();
		m_outMapImageEndGpsDataOut.write();
		uhwResult = RESULT_SUCCESS;
	}
	else{
		uhwResult = RESULT_ERROR;
	}

	return uhwResult;
}

/*****************************************************************************************
*	Function Name		：uhwMapDataRangeCheck
*	Description			：地図画像付加データの範囲チェックを行う
*	Argument			：なし
*	Return				：RESULT_SUCCESS:正常終了、RESULT_ERROR：異常終了
******************************************************************************************/
uhword_type MapImageSelect::uhwMapDataRangeCheck(MapDBAddData_st stAddData)
{
	uhword_type uhwLength = 0;
	using namespace std;

	//タイル画像名称のデータ長確認
	uhwLength = stAddData.strTileName.length();
	if((uhwLength == 0) || (uhwLength > MAPDATA_TILE_NAME_LENGTH)){
		std::cout << "[error]Map DB tile name is invalid!! = " << stAddData.strTileName << std::endl;
		return RESULT_ERROR;
	}

	//タイル画像の拡張子の確認
	tr2::sys::path path(stAddData.strTileName);
	if(path.extension() != ".png"){
		std::cout << "[error]File extension is wrong!! = " << stAddData.strTileName << std::endl;
		return RESULT_ERROR;
	}

	//フォルダ名称のデータ長確認
	uhwLength = stAddData.strFolderPath.length();
	if((uhwLength == 0) || (uhwLength > MAPDATA_TILE_FOLDER_PATH_LENGTH)){
		std::cout << "[error]Map DB folder path is invalid!! = " << uhwLength << std::endl;
		return RESULT_ERROR;
	}

	//ズームレベル設定範囲の確認
	if((stAddData.uwZoomLevel < ZOOM_LEVEL_MIN) || (stAddData.uwZoomLevel > ZOOM_LEVEL_MAX)){
		std::cout << "[error]Map DB zoomlevel is invalid!! = " << stAddData.uwZoomLevel << std::endl;
		return RESULT_ERROR;
	}

	//作成日のデータ長確認
	uhwLength = stAddData.strCreateDate.length();
	if((uhwLength == 0) || (uhwLength > 8)){
		std::cout << "[error]Map DB create date is invalid!! = " << stAddData.strCreateDate << std::endl;
		return RESULT_ERROR;
	}

	//合成計画のデータ長確認
	uhwLength = stAddData.strSyntesisPlanName.length();
	if((uhwLength == 0) || (uhwLength > MAPDATA_PLANNAME_LENGTH)){
		std::cout << "[error]Map DB planname is invalid!! = " << stAddData.strSyntesisPlanName << std::endl;
		return RESULT_ERROR;
	}

	return RESULT_SUCCESS;
}

/*****************************************************************************************
*	Function Name		：strUTF8toSjis
*	Description			：UTF-8→Sjis変換
*	Argument			：変換元の文字列
*	Return				：正常終了：変換後の文字列、異常終了：空文字列
******************************************************************************************/
std::string MapImageSelect::strUTF8toSjis(std::string strUTF8)
{
	std::string strSJis = "";
	uhword_type uhwUnicodeLen = 0;
	uhword_type uhwJisLen = 0;
	uhword_type uhwConvResult = 0;
	uword_type uwLogLine = 0;
	wchar_t* bufUnicode = NULL;
	char* bufShiftJis = NULL;

	if(strUTF8 == ""){
		uwLogLine = __LINE__;
		goto SJIS_CONV_ERROR;
	}

	//Unicodeへ変換後の文字列長取得
	uhwUnicodeLen = MultiByteToWideChar(CP_UTF8,0,strUTF8.c_str(),strUTF8.size() + 1,NULL,0);
	if(uhwUnicodeLen == 0){
		uwLogLine = __LINE__;
		goto SJIS_CONV_ERROR;
	}

	//Unicode文字列のバッファを確保
	bufUnicode = new wchar_t[uhwUnicodeLen];
	if(bufUnicode == NULL){
		uwLogLine = __LINE__;
		goto SJIS_CONV_ERROR;
	}

	//UTF8からUnicodeへ変換
	uhwConvResult = MultiByteToWideChar(CP_UTF8,0,strUTF8.c_str(),strUTF8.size() + 1,bufUnicode,uhwUnicodeLen);
	if(uhwConvResult == 0){
		uwLogLine = __LINE__;
		goto SJIS_CONV_ERROR;
	}

	//ShiftJISへ変換後の文字列長取得
	uhwJisLen = WideCharToMultiByte(CP_THREAD_ACP,0,bufUnicode,-1,NULL,0,NULL,NULL);
	if(uhwJisLen == 0){
		uwLogLine = __LINE__;
		goto SJIS_CONV_ERROR;
	}

	//ShiftJIS文字列のバッファを確保
	bufShiftJis = new char[uhwJisLen];
	if(bufShiftJis == NULL){
		uwLogLine = __LINE__;
		goto SJIS_CONV_ERROR;
	}

	//UnicodeからShiftJISへ変換
	uhwConvResult = WideCharToMultiByte(CP_THREAD_ACP,0,bufUnicode,uhwUnicodeLen,bufShiftJis,uhwJisLen,NULL,NULL);
	if(uhwConvResult == 0){
		uwLogLine = __LINE__;
		goto SJIS_CONV_ERROR;
	}

	strSJis = bufShiftJis;

	delete[] bufUnicode;
	delete[] bufShiftJis;

	return strSJis;

SJIS_CONV_ERROR:
	std::cout << "[error]MapImageSelect::strUTF8toSjis = " << GetLastError() << ",line = " << uwLogLine << std::endl;

	if(bufUnicode != NULL){
		delete[] bufUnicode;
	}
	if(bufShiftJis != NULL){
		delete[] bufShiftJis;
	}

	strSJis = "";
	return strSJis;

}

/*****************************************************************************************
*	Function Name		：strFolderPathReplace
*	Description			：作成する地図画像種別に応じてタイル画像保存フォルダパスを置換する
*	Argument			：なし
*	Return				：置換後のタイル画像フォルダパス
******************************************************************************************/
std::string MapImageSelect::strFolderPathReplace(std::string strFolderPath, uword_type uwMapKind)
{
	std::string strPathRepFrom = "";
	std::string strPathRepTo = "";
	std::string strReplacePath = "";

	if(strFolderPath != ""){
		if(uwMapKind == MAP_KIND_DRONE){
			//ドローン画像
			strPathRepFrom = FOLDER_PATH_BASEMAP;
			strPathRepTo = FOLDER_PATH_DRONE;
		}
		else{
			//国土地理院画像
			strPathRepFrom = FOLDER_PATH_DRONE;
			strPathRepTo = FOLDER_PATH_BASEMAP;
		}

		strReplacePath = strFolderPath;

		//地図種別に応じてパスを置換
		std::string::size_type pos = 0;
		while(pos = strReplacePath.find(strPathRepFrom,pos),pos != std::string::npos) {
			strReplacePath.replace(pos,strPathRepFrom.length(),strPathRepTo);
			pos += strPathRepTo.length();
		}
	}
	return strReplacePath;
}

/*****************************************************************************************
*	Function Name		：MapImageNotice
*	Description			：地図画像セレクトコンポーネントの完了通知を返す処理
*	Argument			：なし
*	Return				：なし
******************************************************************************************/
void MapImageSelect::MapImageNotice(uhword_type uhwResult)
{
	uhword_type uhwNotice = NOTICE_INIT;

	if((m_uwMapCreateKind < CREATE_KIND_MAX) && (uhwResult <= RESULT_ERROR)){
		uhwNotice = MapCreateNoticeTbl[uhwResult][m_uwMapCreateKind];
		m_MapImageNoticeProv.usSetMapImageNotice(uhwNotice, NOTICE_PARAM_INIT);
		std::cout << "[debug]usSetMapImageNotice()" << ",param1 = " << uhwNotice << ",param2 = " << NOTICE_PARAM_INIT << std::endl;
	}else{
		std::cout << "[error]usSetMapImageNotice() = " << m_uwMapCreateKind << ", " << uhwResult << std::endl;
	}
}

/******************************************************************************************
*	Function Name		：blMapDBDBReqGetAddDataInfoConsChk
*	Description			：地図画像情報取得要求用のサービスポート接続確認
*	Argument			：なし
*	Return				：TRUE：接続正常/FALSE：接続異常
******************************************************************************************/
bool_type MapImageSelect::blMapDBDBReqGetAddDataInfoConsChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_MapDBReqGetAddDataInfoCons._ptr())){
			std::cout << "[nil]m_MapDBReqGetAddDataInfoCons is not assigned" << std::endl;
			return FALSE;
		}
		else{
			if(m_MapDBReqGetAddDataInfoCons->_non_existent()){
				std::cout << "[inactive]m_MapDBReqGetAddDataInfoCons is inactive" << std::endl;
				return FALSE;
			}
			else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blMapDBReqGetAddDataConsChk
*	Description			：地図画像データ取得要求用のサービスポート接続確認
*	Argument			：なし
*	Return				：TRUE：接続正常/FALSE：接続異常
******************************************************************************************/
bool_type MapImageSelect::blMapDBReqGetAddDataConsChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_MapDBReqGetAddDataCons._ptr())){
			std::cout << "[nil]m_MapDBReqGetAddDataCons is not assigned" << std::endl;
			return FALSE;
		}
		else{
			if(m_MapDBReqGetAddDataCons->_non_existent()){
				std::cout << "[inactive]m_MapDBReqGetAddDataCons is inactive" << std::endl;
				return FALSE;
			}
			else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blMapDBReqGetAddDataConsChk
*	Description			：地図画像データDB制御RTCの完了通知用のサービスポート接続確認
*	Argument			：なし
*	Return				：TRUE：接続正常/FALSE：接続異常
******************************************************************************************/
bool_type MapImageSelect::blMapDataDBNoticeConsChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_MapDataDBNoticeCons._ptr())){
			std::cout << "[nil]m_MapDataDBNoticeCons is not assigned" << std::endl;
			return FALSE;
		}
		else{
			if(m_MapDataDBNoticeCons->_non_existent()){
				std::cout << "[inactive]m_MapDataDBNoticeCons is inactive" << std::endl;
				return FALSE;
			}
			else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：MapImgSelInit
*	Description			：メンバ変数初期化
*	Argument			：なし
*	Return				：なし
******************************************************************************************/
void MapImageSelect::MapImgSelInit(void)
{
	m_uhwMatrixTriger = TRG_NON;
	m_uhwMatrixMode = MODE_DISP_OFF;
	m_uhwMatrixActID = ACT_NON;
	
	m_uwMapDBNotice = NOTICE_INIT;
	m_uwSelImageGroupId = GROUP_ID_NON;
	m_uwScrollArrow = ARROW_DEF;
	m_uwAdjZoom = ZOOM_ADJ_OFF;
	m_uwZoomLevel = ZOOM_LEVEL_DEF;
	m_uwMapKind = MAP_CHENGE_DEF;

	memset(&m_stMapDBAddInfo,0,sizeof(MapDBAddInfo_st));
	MapAddDataInit();

	m_uwMapDBGetCnt = 0;
	m_uwTileNoXStart = 1;
	m_uwTileNoYStart = 1;
	m_uwTileNoXEnd = 1;
	m_uwTileNoXEnd = 1;
	m_uwMapCreateKind = CREATE_KIND_SELECT;

	//サービスポート初期化
	m_MapImageReqSelectImageProv.InitMapImageReqSelectImage();
	m_MapImageReqScrollProv.InitMapImageReqScroll();
	m_MapImageReqAdjZoomProv.InitMapImageReqAdjZoom();
	m_MapImageReqAdjMapChangeProv.InitMapImageReqAdjMapChange();
	m_MapImageNoticeProv.InitMapImageNotice();
}

/******************************************************************************************
*	Function Name		：MapAddDataInit
*	Description			：地図データDB画像付加データ保存変数初期化
*	Argument			：なし
*	Return				：なし
******************************************************************************************/
void MapImageSelect::MapAddDataInit(void)
{
	uhword_type uhwCnt = 0;

	for(uhwCnt = 0; uhwCnt < TILE_MAX_NUM ; uhwCnt ++){
		m_stMapDBAddData.stTile[uhwCnt].strTileName = "";
		m_stMapDBAddData.stTile[uhwCnt].strFolderPath = "";
		m_stMapDBAddData.stTile[uhwCnt].uwZoomLevel = ZOOM_LEVEL_DEF;
		m_stMapDBAddData.stTile[uhwCnt].uwTileCodeX = 0;
		m_stMapDBAddData.stTile[uhwCnt].uwTileCodeY = 0;
		m_stMapDBAddData.stTile[uhwCnt].dStartLatitude = 0;
		m_stMapDBAddData.stTile[uhwCnt].dStartLongitude = 0;
		m_stMapDBAddData.stTile[uhwCnt].dEndLatitude = 0;
		m_stMapDBAddData.stTile[uhwCnt].dEndLongitude = 0;
		m_stMapDBAddData.stTile[uhwCnt].strCreateDate = "";
		m_stMapDBAddData.stTile[uhwCnt].strSyntesisPlanName = "";
	}
}

/******************************************************************************************
*	Function Name		：uhwZoomLevelAdjCheck
*	Description			：DBにズームレベル調整時の画像があるか確認する
*	Argument			：なし
*	Return				：正常終了：調整可能/異常終了：調整付加
******************************************************************************************/
uhword_type MapImageSelect::uhwZoomLevelAdjCheck(void)
{
	bool_type blZoom19 = FALSE;
	bool_type blZoom20 = FALSE;
	bool_type blZoom21 = FALSE;

	if(m_stMapDBAddInfo.uwKeepZoomLevel & MASK_ZOOM_19){
		blZoom19 = TRUE;
	}
	
	if(m_stMapDBAddInfo.uwKeepZoomLevel & MASK_ZOOM_20){
		blZoom20 = TRUE;
	}

	if(m_stMapDBAddInfo.uwKeepZoomLevel & MASK_ZOOM_21){
		blZoom21 = TRUE;
	}

	//up
	switch(m_uwZoomLevel){
	case ZOOM_LEVEL_18:
		if(m_uwAdjZoom == ZOOM_ADJ_UP){
			//Up方向に調整
			if(blZoom19){
				m_uwZoomLevel = ZOOM_LEVEL_19;
			}
			else if(blZoom20){
				m_uwZoomLevel = ZOOM_LEVEL_20;
			}
			else if(blZoom21){
				m_uwZoomLevel = ZOOM_LEVEL_21;
			}
			else{
				goto ZOOM_LEVEL_ADJ_CHKERR;
			}
		}
		else{
			//Down方向に調整
			goto ZOOM_LEVEL_ADJ_CHKERR;
		}
		break;

	case ZOOM_LEVEL_19:
		if(m_uwAdjZoom == ZOOM_ADJ_UP){
			//Up方向に調整
			if(blZoom20){
				m_uwZoomLevel = ZOOM_LEVEL_20;
			}
			else if(blZoom21){
				m_uwZoomLevel = ZOOM_LEVEL_21;
			}
			else{
				goto ZOOM_LEVEL_ADJ_CHKERR;
			}
		}
		else{
			//Down方向に調整
			m_uwZoomLevel = ZOOM_LEVEL_18;
		}
		break;

	case ZOOM_LEVEL_20:
		if(m_uwAdjZoom == ZOOM_ADJ_UP){
			//Up方向に調整
			if(blZoom21){
				m_uwZoomLevel = ZOOM_LEVEL_21;
			}
			else{
				goto ZOOM_LEVEL_ADJ_CHKERR;
			}
		}
		else{
			//Down方向に調整
			if(blZoom19){
				m_uwZoomLevel = ZOOM_LEVEL_19;
			}
			else{
				m_uwZoomLevel = ZOOM_LEVEL_18;
			}
		}
		break;

	case ZOOM_LEVEL_21:
		if(m_uwAdjZoom == ZOOM_ADJ_UP){
			//Up方向に調整
			goto ZOOM_LEVEL_ADJ_CHKERR;
		}
		else{
			//Down方向に調整
			if(blZoom20){
				m_uwZoomLevel = ZOOM_LEVEL_20;
			}
			else if(blZoom19){
				m_uwZoomLevel = ZOOM_LEVEL_19;
			}
			else{
				m_uwZoomLevel = ZOOM_LEVEL_18;
			}
		}
		break;

	default:
		goto ZOOM_LEVEL_ADJ_CHKERR;
	}

	return RESULT_SUCCESS;

ZOOM_LEVEL_ADJ_CHKERR:
	std::cout << "[warning]Can not adjust zoom level!! = " << m_uwAdjZoom << ", " << m_uwZoomLevel << std::endl;
	return RESULT_ERROR;
}

/*****************************************************************************************
*	Function Name		：strMapJsonDataReplace
*	Description			：Jsonデータを置換('→")など
*	Argument			：画像付加データDBから取得したJsonデータ
*	Return				：JsonCppで使用可能なJsonデータ
******************************************************************************************/
std::string MapImageSelect::strMapJsonDataReplace(std::string strInputData)
{
	std::string strRepAddData = "";
	std::string strPathRepFrom = "'";
	std::string strPathRepTo = "\"";

	strRepAddData = strInputData;

	//シングルクォーテーションをダブルクォーテーションに置換
	std::string::size_type pos = 0;
	while(pos = strRepAddData.find(strPathRepFrom, pos), pos != std::string::npos) {
		strRepAddData.replace(pos, strPathRepFrom.length(), strPathRepTo);
		pos += strPathRepTo.length();
	}

	strPathRepFrom = " u";
	strPathRepTo = " ";
	pos = 0;
	//エスケープを削除
	while(pos = strRepAddData.find(strPathRepFrom, pos), pos != std::string::npos) {

		strRepAddData.replace(pos, strPathRepFrom.length(), strPathRepTo);
		pos += strPathRepTo.length();
	}

	strPathRepFrom = "[\"";
	strPathRepTo = "";
	pos = 0;
	while(pos = strRepAddData.find(strPathRepFrom, pos), pos != std::string::npos) {

		strRepAddData.replace(pos, strPathRepFrom.length(), strPathRepTo);
		pos += strPathRepTo.length();
	}

	strPathRepFrom = "\"]";
	strPathRepTo = "";
	pos = 0;
	while(pos = strRepAddData.find(strPathRepFrom, pos), pos != std::string::npos) {

		strRepAddData.replace(pos, strPathRepFrom.length(), strPathRepTo);
		pos += strPathRepTo.length();
	}

	strRepAddData.erase(1, 1);

	return strRepAddData;
}

/*****************************************************************************************
*	Function Name		：MapImgSelModeSet
*	Description			：マトリクスモード更新処理
*	Argument			：更新モード
*	Return				：なし
******************************************************************************************/
void MapImageSelect::MapImgSelModeSet(uhword_type uhwMode)
{
	m_uhwMatrixMode = uhwMode;
	std::cout << "[debug]Matrix Mode = " << m_uhwMatrixMode << std::endl;
}

extern "C"
{
 
  void MapImageSelectInit(RTC::Manager* manager)
  {
    coil::Properties profile(mapimageselect_spec);
    manager->registerFactory(profile,
                             RTC::Create<MapImageSelect>,
                             RTC::Delete<MapImageSelect>);
  }
  
};


